var Stage = require("../models/stage.js");
var winston = require('winston');
var vm = require('vm');
var fs = require("fs");
var path = require("path");
var mkdirp = require('mkdirp');
var async = require('async');
var sherlockFile = path.join('.', 'sherlock.json');
var sherlockConfig={};
var SherlockContext = require('../context/sherlockContext.js');
var SherlockJobExecutor = require('../context/sherlockJobExecutor');
var config={};

//###########################################
//###### Configuring Stage
//###########################################
var loadDefaultJobStage = new Stage("Load default jobs");

var jobs = [];
var choices=[];

if(sherlockFile && fs.existsSync(sherlockFile)){
	winston.debug('Loading ' + sherlockFile);
	configContent = fs.readFileSync(sherlockFile);
	sherlockConfig = JSON.parse(configContent);
	winston.debug('sherlock.json: ',  sherlockConfig);
}

if(sherlockConfig.jobsLocation){
	sherlockConfig.jobsLocation = path.resolve(sherlockConfig.jobsLocation);
	winston.debug("Loading jobs from: " + sherlockConfig.jobsLocation);
}

if(sherlockConfig.jobsLocation && fs.existsSync(sherlockConfig.jobsLocation)){
	winston.debug('Loading jobs from '+sherlockConfig.jobsLocation);
	var jobPath = path.join(sherlockConfig.jobsLocation);
	jobs = fs.readdirSync(jobPath);
	console.log(jobs.length + ' jobs was founded');

	for (var i = jobs.length - 1; i >= 0; i--) {
		var job = jobs[i];
		winston.debug(job);
		choices.push(job);
	};
}else{
	winston.debug('No jobs found in '+sherlockConfig.jobsLocation);
}

loadDefaultJobStage.applyWhen(function(answers){
	return choices.length > 0;
});

loadDefaultJobStage.addQuestion({
	type: "list",
	name: "selectedJob",
	message: "Select one job to run",
	choices: choices.sort()
});
//###########################################
//###### Configuring Stage
//###########################################
loadDefaultJobStage.after(function(answers, callback){
	var jobPath = path.join(sherlockConfig.jobsLocation, answers.selectedJob);
	SherlockJobExecutor.run(jobPath, {}, function(conclusions){
		callback();
	});
});

module.exports = loadDefaultJobStage;